@@ -35,7 +35,10 @@ _common_options = [
     click.option("--saved", is_flag=True, default=None),
     click.option("--search", type=str, default=None),
     click.option(
-        "-S", "--sort", type=click.Choice(("hot", "top", "new", "controversial", "rising", "relevance")), default=None
+        "-S",
+        "--sort",
+        type=click.Choice(("hot", "top", "new", "controversial", "rising", "relevance")),
+        default=None,
     ),
     click.option("--submitted", is_flag=True, default=None),
     click.option("-s", "--subreddit", type=str, multiple=True, default=None),
@@ -96,7 +99,6 @@ def _check_version(context: click.core.Context, _param, value: bool) -> None:  #
 )
 def cli() -> None:
     """BDFRx is used to download content from Reddit."""
-    pass
 
 
 @cli.command("download")
@@ -148,8 +150,7 @@ def cli_completion(context: click.Context, **_) -> None:
 def make_console_logging_handler(verbosity: int) -> logging.StreamHandler:
     class StreamExceptionFilter(logging.Filter):
         def filter(self, record: logging.LogRecord) -> bool:  # noqa: A003
-            result = not (record.levelno == logging.ERROR and record.exc_info)
-            return result
+            return not (record.levelno == logging.ERROR and record.exc_info)
 
     logger.setLevel(1)
     stream = logging.StreamHandler(sys.stdout)
