@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import configparser
 import importlib.resources
 import itertools
@@ -122,7 +120,9 @@ class RedditConnector(metaclass=ABCMeta):
             self.args.disable_module = [self.cfg_parser.get("DEFAULT", "disabled_modules", fallback="")]
         if not self.args.filename_restriction_scheme:
             self.args.filename_restriction_scheme = self.cfg_parser.get(
-                "DEFAULT", "filename_restriction_scheme", fallback=None
+                "DEFAULT",
+                "filename_restriction_scheme",
+                fallback=None,
             )
             logger.debug(f"Setting filename restriction scheme to {self.args.filename_restriction_scheme!r}")
         # Update config on disk
@@ -199,11 +199,10 @@ class RedditConnector(metaclass=ABCMeta):
 
     def load_config(self) -> None:
         self.cfg_parser = configparser.ConfigParser()
-        if self.args.config:
-            if (cfg_path := Path(self.args.config)).exists():
-                self.cfg_parser.read(cfg_path)
-                self.config_location = cfg_path
-                return
+        if self.args.config and (cfg_path := Path(self.args.config)).exists():
+            self.cfg_parser.read(cfg_path)
+            self.config_location = cfg_path
+            return
         possible_paths = [
             Path("./config.cfg"),
             Path("./default_config.cfg"),
@@ -230,12 +229,11 @@ class RedditConnector(metaclass=ABCMeta):
                 logger.debug(f"Loading DB from {self.args.db_file}")
                 self.db = sqlite3.connect(db_path)
                 return
-            else:
-                with importlib.resources.path("bdfrx", "bdfrx.db") as path:
-                    logger.info(f"DB not found at {self.args.db_file} loading clean DB")
-                    shutil.copy(path, Path(self.args.db_file))
-                    self.db = sqlite3.connect(self.args.db_file)
-                    return
+            with importlib.resources.path("bdfrx", "bdfrx.db") as path:
+                logger.info(f"DB not found at {self.args.db_file} loading clean DB")
+                shutil.copy(path, Path(self.args.db_file))
+                self.db = sqlite3.connect(self.args.db_file)
+                return
         possible_paths = [
             Path("./bdfrx.db"),
             Path(self.config_directory, "bdfrx.db"),
@@ -271,8 +269,10 @@ class RedditConnector(metaclass=ABCMeta):
                 file_handler.doRollover()
             except PermissionError:
                 logger.critical(
-                    "Cannot rollover logfile, make sure this is the only "
-                    "BDFRx process or specify alternate logfile location"
+                    (
+                        "Cannot rollover logfile, make sure this is the only "
+                        "BDFRx process or specify alternate logfile location"
+                    ),
                 )
                 raise
         formatter = logging.Formatter("[%(asctime)s - %(name)s - %(levelname)s] - %(message)s")
@@ -297,7 +297,7 @@ class RedditConnector(metaclass=ABCMeta):
             all_entries.extend([RedditConnector.sanitise_subreddit_name(name) for name in results])
         return set(all_entries)
 
-    def get_subreddits(self) -> list[praw.models.ListingGenerator]:
+    def get_subreddits(self) -> list[praw.models.ListingGenerator]:  # noqa: PLR0912
         out = []
         subscribed_subreddits = set()
         if self.args.subscribed:
@@ -310,12 +310,12 @@ class RedditConnector(metaclass=ABCMeta):
             else:
                 logger.error("Cannot find subscribed subreddits without an authenticated instance")
         if self.args.subreddit or subscribed_subreddits:
-            for reddit in self.split_args_input(self.args.subreddit) | subscribed_subreddits:
-                if reddit == "friends" and self.authenticated is False:
+            for subreddit in self.split_args_input(self.args.subreddit) | subscribed_subreddits:
+                if subreddit == "friends" and self.authenticated is False:
                     logger.error("Cannot read friends subreddit without an authenticated instance")
                     continue
                 try:
-                    reddit = self.reddit_instance.subreddit(reddit)
+                    reddit = self.reddit_instance.subreddit(subreddit)
                     try:
                         self.check_subreddit_status(reddit)
                     except errors.BulkDownloaderException as e:
@@ -328,10 +328,10 @@ class RedditConnector(metaclass=ABCMeta):
                                 sort=self.sort_filter.name.lower(),
                                 limit=self.args.limit,
                                 time_filter=self.time_filter.value,
-                            )
+                            ),
                         )
                         logger.debug(
-                            f"Added submissions from subreddit {reddit} with the search term {self.args.search!r}"
+                            f"Added submissions from subreddit {reddit} with the search term {self.args.search!r}",
                         )
                     else:
                         out.append(self.create_filtered_listing_generator(reddit))
@@ -346,10 +346,9 @@ class RedditConnector(metaclass=ABCMeta):
                 resolved_name = self.reddit_instance.user.me().name
                 logger.log(9, f"Resolved user to {resolved_name}")
                 return resolved_name
-            else:
-                logger.warning("To use 'me' as a user, an authenticated Reddit instance must be used")
-        else:
-            return in_name
+            logger.warning("To use 'me' as a user, an authenticated Reddit instance must be used")
+            return None
+        return in_name
 
     def get_submissions_from_link(self) -> list[list[praw.models.Submission]]:
         supplied_submissions = []
@@ -379,9 +378,9 @@ class RedditConnector(metaclass=ABCMeta):
                 logger.error("Only 1 user can be supplied when retrieving from multireddits")
                 return []
             out = []
-            for multi in self.split_args_input(self.args.multireddit):
+            for multi_reddit in self.split_args_input(self.args.multireddit):
                 try:
-                    multi = self.reddit_instance.multireddit(redditor=self.args.user[0], name=multi)
+                    multi = self.reddit_instance.multireddit(redditor=self.args.user[0], name=multi_reddit)
                     if not multi.subreddits:
                         raise errors.BulkDownloaderException
                     out.append(self.create_filtered_listing_generator(multi))
@@ -392,7 +391,8 @@ class RedditConnector(metaclass=ABCMeta):
         return []
 
     def create_filtered_listing_generator(
-        self, reddit_source: Union[praw.models.Subreddit, praw.models.Multireddit, praw.models.Redditor.submissions]
+        self,
+        reddit_source: Union[praw.models.Subreddit, praw.models.Multireddit, praw.models.Redditor.submissions],
     ) -> Iterator:
         sort_function = self.determine_sort_function()
         if self.sort_filter in (RedditTypes.SortType.TOP, RedditTypes.SortType.CONTROVERSIAL):
@@ -417,7 +417,7 @@ class RedditConnector(metaclass=ABCMeta):
                         generators.append(
                             self.create_filtered_listing_generator(
                                 self.reddit_instance.redditor(user).submissions,
-                            )
+                            ),
                         )
                     if not self.authenticated and any((self.args.upvoted, self.args.saved)):
                         logger.warning("Accessing user lists requires authentication")
@@ -448,7 +448,10 @@ class RedditConnector(metaclass=ABCMeta):
 
     def create_file_name_formatter(self) -> FileNameFormatter:
         return FileNameFormatter(
-            self.args.file_scheme, self.args.folder_scheme, self.args.time_format, self.args.filename_restriction_scheme
+            self.args.file_scheme,
+            self.args.folder_scheme,
+            self.args.time_format,
+            self.args.filename_restriction_scheme,
         )
 
     def create_time_filter(self) -> RedditTypes.TimeType:
@@ -490,8 +493,8 @@ class RedditConnector(metaclass=ABCMeta):
     @staticmethod
     def read_id_files(file_locations: list[str]) -> set[str]:
         out = []
-        for id_file in file_locations:
-            id_file = Path(id_file).resolve().expanduser()
+        for location in file_locations:
+            id_file = Path(location).resolve().expanduser()
             if not id_file.exists():
                 logger.warning(f"ID file at {id_file} does not exist")
                 continue
