@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import datetime
 import logging
 import platform
@@ -55,7 +53,7 @@ class FileNameFormatter:
         else:
             raise BulkDownloaderException(f"Cannot name object {type(submission).__name__}")
         result = format_string
-        for key in attributes.keys():
+        for key in attributes:
             if re.search(rf"(?i).*{{{key}}}.*", result):
                 key_value = str(attributes.get(key, "unknown"))
                 key_value = FileNameFormatter._convert_unicode_escapes(key_value)
@@ -83,7 +81,7 @@ class FileNameFormatter:
         return in_string
 
     def _generate_name_dict_from_submission(self, submission: Submission) -> dict:
-        submission_attributes = {
+        return {
             "title": submission.title,
             "subreddit": submission.subreddit.display_name,
             "redditor": submission.author.name if submission.author else "DELETED",
@@ -92,7 +90,6 @@ class FileNameFormatter:
             "flair": submission.link_flair_text,
             "date": self._convert_timestamp(submission.created_utc),
         }
-        return submission_attributes
 
     def _convert_timestamp(self, timestamp: float) -> str:
         input_time = datetime.datetime.fromtimestamp(timestamp)
@@ -101,7 +98,7 @@ class FileNameFormatter:
         return input_time.strftime(self.time_format_string)
 
     def _generate_name_dict_from_comment(self, comment: Comment) -> dict:
-        comment_attributes = {
+        return {
             "title": comment.submission.title,
             "subreddit": comment.subreddit.display_name,
             "redditor": comment.author.name if comment.author else "DELETED",
@@ -110,7 +107,6 @@ class FileNameFormatter:
             "flair": "",
             "date": self._convert_timestamp(comment.created_utc),
         }
-        return comment_attributes
 
     def format_path(
         self,
@@ -158,7 +154,7 @@ class FileNameFormatter:
                 len(filename) > max_file_part_length_chars,
                 len(filename.encode()) > max_file_part_length_bytes,
                 len(str(out)) > max_path_length,
-            ]
+            ],
         ):
             filename = filename[:-1]
             if not safe_ending and filename[-1] != ".":
@@ -174,8 +170,7 @@ class FileNameFormatter:
         except (ValueError, subprocess.CalledProcessError, OSError):
             if platform.system() == "Windows":
                 return FileNameFormatter.WINDOWS_MAX_PATH_LENGTH
-            else:
-                return FileNameFormatter.LINUX_MAX_PATH_LENGTH
+            return FileNameFormatter.LINUX_MAX_PATH_LENGTH
 
     def format_resource_paths(
         self,
@@ -203,12 +198,14 @@ class FileNameFormatter:
     def validate_string(test_string: str) -> bool:
         if not test_string:
             return False
-        result = any([f"{{{key}}}" in test_string.lower() for key in FileNameFormatter.key_terms])
+        result = any(f"{{{key}}}" in test_string.lower() for key in FileNameFormatter.key_terms)
         if result:
             if "POSTID" not in test_string:
                 logger.warning(
-                    "Some files might not be downloaded due to name conflicts as filenames are"
-                    " not guaranteed to be be unique without {POSTID}"
+                    (
+                        "Some files might not be downloaded due to name conflicts as filenames are"
+                        " not guaranteed to be be unique without {POSTID}"
+                    ),
                 )
             return True
         return False
@@ -223,5 +220,4 @@ class FileNameFormatter:
 
     @staticmethod
     def _strip_emojis(input_string: str) -> str:
-        result = input_string.encode("ascii", errors="ignore").decode("utf-8")
-        return result
+        return input_string.encode("ascii", errors="ignore").decode("utf-8")
