@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import hashlib
 import logging
 import re
@@ -19,7 +17,11 @@ logger = logging.getLogger(__name__)
 
 class Resource:
     def __init__(
-        self, source_submission: Submission, url: str, download_function: Callable, extension: str = None
+        self,
+        source_submission: Submission,
+        url: str,
+        download_function: Callable,
+        extension: str = None,
     ) -> None:
         self.source_submission = source_submission
         self.content: Optional[bytes] = None
@@ -58,26 +60,23 @@ class Resource:
         match = re.search(extension_pattern, stripped_url)
         if match:
             return match.group(1)
+        return None
 
     @staticmethod
     def http_download(url: str, download_parameters: dict) -> Optional[bytes]:
         headers = download_parameters.get("headers")
         current_wait_time = 60
-        if "max_wait_time" in download_parameters:
-            max_wait_time = download_parameters["max_wait_time"]
-        else:
-            max_wait_time = 300
+        max_wait_time = download_parameters.get("max_wait_time", 300)
         while True:
             try:
                 response = requests.get(url, headers=headers, timeout=16)
                 if re.match(r"^2\d{2}", str(response.status_code)) and response.content:
                     return response.content
-                elif response.status_code in (408, 429):
+                if response.status_code in (408, 429):
                     raise requests.exceptions.ConnectionError(f"Response code {response.status_code}")
-                else:
-                    raise BulkDownloaderException(
-                        f"Unrecoverable error requesting resource: HTTP Code {response.status_code}"
-                    )
+                raise BulkDownloaderException(
+                    f"Unrecoverable error requesting resource: HTTP Code {response.status_code}",
+                )
             except (
                 requests.exceptions.ConnectionError,
                 requests.exceptions.ChunkedEncodingError,
