@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import logging
 from typing import Optional
 
@@ -35,3 +33,4 @@ class YtdlpFallback(BaseFallbackDownloader, Youtube):
             return False
         if attributes:
             return True
+        return False
