@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import logging
 from typing import Optional
 
@@ -24,7 +22,7 @@ class SelfPost(BaseDownloader):
 
     def export_to_string(self) -> str:
         """Self posts are formatted here"""
-        content = (
+        return (
             "## ["
             + self.post.fullname
             + "]("
@@ -42,4 +40,3 @@ class SelfPost(BaseDownloader):
             + (self.post.author.name if self.post.author else "DELETED")
             + ")"
         )
-        return content
