@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import platform
 import sys
 import unittest.mock
@@ -34,8 +32,7 @@ def submission() -> MagicMock:
 
 @pytest.fixture()
 def test_formatter() -> FileNameFormatter:
-    out = FileNameFormatter("{TITLE}", "", "ISO")
-    return out
+    return FileNameFormatter("{TITLE}", "", "ISO")
 
 
 def check_valid_windows_path(test_string: str):
@@ -156,7 +153,10 @@ def test_format_name_real(
     ),
 )
 def test_format_full(
-    format_string_directory: str, format_string_file: str, expected: str, reddit_submission: praw.models.Submission
+    format_string_directory: str,
+    format_string_file: str,
+    expected: str,
+    reddit_submission: praw.models.Submission,
 ):
     test_resource = Resource(reddit_submission, "i.reddit.com/blabla.png", lambda: None)
     test_formatter = FileNameFormatter(format_string_file, format_string_directory, "ISO")
@@ -175,7 +175,9 @@ def test_format_full(
     ),
 )
 def test_format_full_conform(
-    format_string_directory: str, format_string_file: str, reddit_submission: praw.models.Submission
+    format_string_directory: str,
+    format_string_file: str,
+    reddit_submission: praw.models.Submission,
 ):
     test_resource = Resource(reddit_submission, "i.reddit.com/blabla.png", lambda: None)
     test_formatter = FileNameFormatter(format_string_file, format_string_directory, "ISO")
@@ -259,7 +261,10 @@ def test_limit_filename_length(test_filename: str, test_ending: str, test_format
     ),
 )
 def test_preserve_id_append_when_shortening(
-    test_filename: str, test_ending: str, expected_end: str, test_formatter: FileNameFormatter
+    test_filename: str,
+    test_ending: str,
+    expected_end: str,
+    test_formatter: FileNameFormatter,
 ):
     result = test_formatter.limit_file_name_length(test_filename, test_ending, Path())
     assert len(result.name) <= 255
@@ -348,7 +353,7 @@ def test_generate_dict_for_submission(test_submission_id: str, expected: dict, r
     test_submission = reddit_instance.submission(id=test_submission_id)
     test_formatter = FileNameFormatter("{TITLE}", "", "ISO")
     result = test_formatter._generate_name_dict_from_submission(test_submission)
-    assert all([result.get(key) == expected[key] for key in expected.keys()])
+    assert all(result.get(key) == expected[key] for key in expected)
 
 
 @pytest.mark.online
@@ -371,7 +376,7 @@ def test_generate_dict_for_comment(test_comment_id: str, expected: dict, reddit_
     test_comment = reddit_instance.comment(id=test_comment_id)
     test_formatter = FileNameFormatter("{TITLE}", "", "ISO")
     result = test_formatter._generate_name_dict_from_comment(test_comment)
-    assert all([result.get(key) == expected[key] for key in expected.keys()])
+    assert all(result.get(key) == expected[key] for key in expected)
 
 
 @pytest.mark.online
@@ -487,13 +492,15 @@ def test_get_max_path_length():
 
 
 def test_windows_max_path(tmp_path: Path):
-    with unittest.mock.patch("platform.system", return_value="Windows"):
-        with unittest.mock.patch("bdfrx.file_name_formatter.FileNameFormatter.find_max_path_length", return_value=260):
-            mock = MagicMock()
-            mock.max_path = 260
-            result = FileNameFormatter.limit_file_name_length(mock, "test" * 100, "_1.png", tmp_path)
-            assert len(str(result)) <= 260
-            assert len(result.name) <= (260 - len(str(tmp_path)))
+    with unittest.mock.patch("platform.system", return_value="Windows") and unittest.mock.patch(
+        "bdfrx.file_name_formatter.FileNameFormatter.find_max_path_length",
+        return_value=260,
+    ):
+        mock = MagicMock()
+        mock.max_path = 260
+        result = FileNameFormatter.limit_file_name_length(mock, "test" * 100, "_1.png", tmp_path)
+        assert len(str(result)) <= 260
+        assert len(result.name) <= (260 - len(str(tmp_path)))
 
 
 @pytest.mark.online
@@ -529,7 +536,10 @@ def test_name_submission(
     ),
 )
 def test_shortened_file_name_ending(
-    test_filename: str, test_ending: str, expected_end: str, test_formatter: FileNameFormatter
+    test_filename: str,
+    test_ending: str,
+    expected_end: str,
+    test_formatter: FileNameFormatter,
 ):
     result = test_formatter.limit_file_name_length(test_filename, test_ending, Path())
     assert result.name.endswith(expected_end)
